@@ -71,6 +71,10 @@ __all__ = [
     "dcopy",
 ]
 
+
+import lovely_tensors as lt
+lt.monkey_patch()
+
 from .logger import *
 from .bb_utils import *
 from pathlib import Path
